<?php

admin::CheckRank($config['minRankManagePolls']);

if (!isset($_GET['poll_id'])) {
    header('Location: /adminpan/polls');
    exit;
}

$pollExistente = $dbh->prepare('SELECT * FROM cms_polls WHERE id = :id');
$pollExistente->bindParam(':id', $_GET['poll_id']);
$pollExistente->execute();

$pollExistente = $pollExistente->rowCount() > 0 ? $pollExistente->fetch(PDO::FETCH_ASSOC) : null;

?>

<!DOCTYPE html>

<html lang="en">

<head>
    <?php include_once("includes/head.php") ?>

    <script type="text/javascript">
        function editPoll(e) {
            let btnEditPoll = $('#btnEditPoll');

            let poll_id = $('#poll_id');
            let titulo = $('#titulo');
            let descricao = $("#descricao");
            let data_encerramento = (new Date($("#data_encerramento").val())).getTime();
            let precisa_login = $("#precisa_login");
            let votos_por_usuario = $("#votos_por_usuario");
            let ativada = $("#ativada");

            btnEditPoll.prop('disabled', true);

            $.ajax({
                type: "POST",
                url: "../api/edit_poll.php",
                async: true,
                data: {
                    'poll_id': poll_id.val(),
                    'titulo': titulo.val(),
                    'descricao': descricao.val(),
                    'data_encerramento': data_encerramento / 1000,
                    'precisa_login': precisa_login.val(),
                    'votos_por_usuario': votos_por_usuario.val(),
                    'ativada': ativada.val()
                },
                success: function(response) {
                    console.log("SUCESSO:", response);

                    if (response.success) {
                        var msgSucesso = 'Votação atualizada com sucesso!';
                        $(".alert").removeClass('alert-danger');
                        $(".alert").addClass('alert-success');
                        $(".alert").css('display', 'block');
                        $("#alerta-sucesso-erro").text(msgSucesso);
                        alert(msgSucesso);
                    } else {
                        $(".alert").removeClass('alert-success');
                        $(".alert").addClass('alert-danger');
                        $(".alert").css('display', 'block');
                        $("#alerta-sucesso-erro").text("Desculpe, não foi possível atualizar esta votação. Contate um desenvolvedor.");
                    }
                },
                error: function(error) {
                    console.log("ERRO:", error);
                    $("#alerta-sucesso-erro").text("Ocorreu um erro. Por favor contate um Staff.");
                },
                complete: function() {
                    btnEditPoll.prop('disabled', false);
                }
            });

            return false;
        }

        function handlePrecisaLogin(value) {
            let selectVotos = document.getElementById('votos_por_usuario');
            let labelVotos = document.getElementById('labelVotos');

            if (value === '1') {
                selectVotos.disabled = false;
                labelVotos.style.textDecoration = 'none';
            } else {
                selectVotos.disabled = true;
                labelVotos.style.textDecoration = 'line-through';
                selectVotos.value = 'ilimitado';
            }
        }

        function getPollAnswers(e) {
            $.ajax({
                type: "GET",
                url: "../api/get_poll_answers.php",
                async: true,
                data: {
                    'poll_id': $('#poll_id').val(),
                },
                success: function(response) {
                    console.log("SUCESSO:", response);

                    var entries = Object.entries(response);
                    console.log(entries);
                    for (var i = 0; i < entries.length; i++) {
                        //console.log(entries[i][0] + ': ' + entries[i][1]);
                        $("#votos_" + entries[i][0]).val(entries[i][1]);
                    }

                    // ...
                },
                error: function(error) {
                    console.log("ERRO:", error);

                    // ...
                },
                complete: function() {
                    // ...
                }
            });
        }

        setInterval(function() {
            getPollAnswers();
        }, 10000);
    </script>
</head>

<body class="c-app c-dark-theme c-no-layout-transition">
    <?php include_once("includes/navi.php") ?>

    <div class="c-wrapper">
        <?php include_once("includes/header.php") ?>

        <div class="c-body">
            <main class="c-main">
                <div class="container-fluid">
                    <div class="fade-in">
                        <div class="row">
                            <div class="col-md-12">
                                <div class="card">
                                    <div class="card-header">Editar votação</div>
                                    <div class="card-body">
                                        <?php if ($pollExistente != null) { ?>
                                            <form method="POST" onsubmit="return editPoll()">
                                                <div class="alert alert-block alert-danger" style="display: none"><strong id="alerta-sucesso-erro"></strong></div>

                                                <input type="hidden" id="poll_id" name="poll_id" value="<?= $pollExistente['id'] ?>">
                                                <div class="form-group">
                                                    <label class="control-label">Título da Votação</label>
                                                    <input type="text" id="titulo" name="titulo" class="form-control" placeholder="Ex.: Big Brother Lella" minlength="1" maxlength="50" value="<?= htmlspecialchars($pollExistente['titulo'], ENT_QUOTES, 'UTF-8') ?>">
                                                </div>
                                                <div class="form-group">
                                                    <label class="control-label">Descrição da Votação</label>
                                                    <input type="text" id="descricao" name="descricao" class="form-control" placeholder="Ex.: Decida quem vai levar o prêmio pra casa!" minlength="1" maxlength="100" value="<?= htmlspecialchars($pollExistente['descricao'], ENT_QUOTES, 'UTF-8') ?>">
                                                </div>
                                                <div class="form-group">
                                                    <label class="control-label">Data de encerramento</label>
                                                    <input type="datetime-local" id="data_encerramento" name="data_encerramento" class="form-control" value="<?= date('Y-m-d', $pollExistente['data_encerramento']) ?>T<?= date('H:i', $pollExistente['data_encerramento']) ?>">
                                                </div>
                                                <div class="form-group">
                                                    <label class="control-label">Precisa estar logado para votar</label>
                                                    <select class="form-control" id="precisa_login" name="precisa_login" onchange="handlePrecisaLogin(this.value)">
                                                        <option value="1" <?= $pollExistente['precisa_login'] == '1' ? 'selected' : '' ?>>Sim</option>
                                                        <option value="0" <?= $pollExistente['precisa_login'] == '0' ? 'selected' : '' ?>>Não</option>
                                                    </select>
                                                </div>
                                                <div class="form-group">
                                                    <label id="labelVotos" class="control-label" <?= $pollExistente['precisa_login'] == '0' ? "style=\"text-decoration: line-through;\"" : "" ?>>Votos por usuário</label>
                                                    <select class="form-control" id="votos_por_usuario" name="votos_por_usuario" <?= $pollExistente['precisa_login'] == '0' ? "disabled" : "" ?>>
                                                        <option value="ilimitado" <?= $pollExistente['votos_por_usuario'] == null ? 'selected' : '' ?>>Sem limite</option>
                                                        <option value="1" <?= $pollExistente['votos_por_usuario'] == '1' ? 'selected' : '' ?>>1</option>
                                                        <option value="5" <?= $pollExistente['votos_por_usuario'] == '5' ? 'selected' : '' ?>>5</option>
                                                        <option value="10" <?= $pollExistente['votos_por_usuario'] == '10' ? 'selected' : '' ?>>10</option>
                                                        <option value="15" <?= $pollExistente['votos_por_usuario'] == '15' ? 'selected' : '' ?>>15</option>
                                                        <option value="20" <?= $pollExistente['votos_por_usuario'] == '20' ? 'selected' : '' ?>>20</option>
                                                    </select>
                                                </div>
                                                <div class="form-group">
                                                    <label class="control-label">Ativar votação</label>
                                                    <select class="form-control" id="ativada" name="ativada">
                                                        <option value="1" <?= $pollExistente['ativada'] == '1' ? 'selected' : '' ?>>Sim</option>
                                                        <option value="0" <?= $pollExistente['ativada'] == '0' ? 'selected' : '' ?>>Não</option>
                                                    </select>
                                                </div>
                                                <div class="form-group">
                                                    <label class="control-label">Usuários</label>
                                                    <div class="usuarios" style="margin-top: -1rem !important;">
                                                        <?php
                                                        $users = $dbh->prepare("SELECT cms_polls_users.*, players.username AS player_username
																	FROM cms_polls_users
																	INNER JOIN players
																	ON players.id = cms_polls_users.player_id
																	WHERE cms_polls_users.poll_id = :poll_id");
                                                        $users->bindParam(':poll_id', $_GET['poll_id']);
                                                        $users->execute();

                                                        $options = $dbh->prepare('SELECT player_id FROM `cms_polls_users` WHERE poll_id = :poll_id');
                                                        $options->bindParam(':poll_id', $_GET['poll_id']);
                                                        $options->execute();

                                                        $op_arr = array();

                                                        while ($option = $options->fetch()) {
                                                            $respostas = $dbh->prepare("SELECT id FROM cms_polls_answers WHERE poll_id = :poll_id AND resposta = :resposta");
                                                            $respostas->bindParam(':poll_id', $_GET['poll_id']);
                                                            $respostas->bindParam(':resposta', $option['player_id']);
                                                            $respostas->execute();

                                                            $op_arr[$option['player_id']] = $respostas->rowCount() . ' votos';
                                                        }

                                                        while ($user = $users->fetch()) {
                                                        ?>
                                                            <div class="form-group row mt-3">
                                                                <div class="col-md-8">
                                                                    <input class="form-control" style="color: rgba(255, 255, 255, 0.5);" type="text" value="<?= $user['player_username'] ?>" disabled>
                                                                </div>
                                                                <div class="col-md-4">
                                                                    <input class="form-control" style="color: rgba(255, 255, 255, 0.5);" type="text" value="<?= $op_arr[$user['player_id']] ?>" disabled>
                                                                </div>
                                                            </div>
                                                            <!-- <div>
                                                                <div class="col-sm-9 p-0 mt-3 pr-2">
                                                                    <input type="text" name="usuarios[0]" maxlength="100" class="form-control" placeholder="Nome do usuário" value="<?= $user['player_username'] ?>" disabled>
                                                                </div>
                                                                <div class="col-sm-3 p-0 mt-3">
                                                                    <input type="text" class="form-control" placeholder="Quantidade de votos" id="votos_<?= $user['player_id'] ?>" value="<?= $op_arr[$user['player_id']] ?>" disabled>
                                                                </div>
                                                            </div> -->
                                                        <?php } ?>
                                                    </div>
                                                </div>
                                                <br>

                                                <button style="width: 130px;float: right;" id="btnEditPoll" name="btnEditPoll" type="submit" class="btn btn-primary">Salvar alterações</button>
                                            </form>
                                        <?php } else { ?>
                                            <div style="padding: 20px;font-size: 11pt"><b>Votação não encontrada.</b></div>
                                        <?php } ?>
                                    </div>
                                </div>
                            </div>
                            <?php if ($pollExistente != null && User::userData('rank') >= $config['minRankViewPollsVotes']) { ?>
                                <div class="col-md-12">
                                    <div class="card">
                                        <div class="card-header">Todos os votos</div>
                                        <div class="card-body">
                                            <table class="table table-responsive-sm table-bordered table-striped table-sm">
                                                <thead>
                                                    <tr>
                                                        <th>Usuário</th>
                                                        <th>Voto computado</th>
                                                        <th>Data</th>
                                                    </tr>
                                                </thead>
                                                <tbody>
                                                    <?php
                                                    $votos = $dbh->prepare('SELECT p1.username AS usuario, p2.username AS resposta, a.timestamp FROM cms_polls_answers AS a
                                                                INNER JOIN players AS p1 ON p1.id=a.data 
                                                                INNER JOIN players AS p2 ON p2.id=a.resposta
                                                                WHERE a.poll_id = :poll_id
                                                                ORDER BY p1.username');
                                                    $votos->bindParam(':poll_id', $_GET['poll_id']);
                                                    $votos->execute();
                                                    while ($voto = $votos->fetch()) { ?>
                                                        <tr>
                                                            <td><?= $voto['usuario'] ?></td>
                                                            <td><?= $voto['resposta'] ?></td>
                                                            <td><?= date('d/m/Y - H:i', $voto['timestamp']) ?></td>
                                                        </tr>
                                                    <?php } ?>
                                                </tbody>
                                            </table>
                                        </div>
                                    </div>
                                </div>
                            <?php } ?>
                        </div>
                    </div>
                </div>
            </main>
        </div>
        <?php include_once("includes/footer.php") ?>
    </div>
</body>

</html>